@@ -4,7 +4,7 @@ function(para) {
     A <- para$para[2]
     G <- para$para[3]
     if(A <= 0 | G <= -1) {
-      warning("Parameters are invalid.")
+      warning("Parameters are invalid")
       return(FALSE)
     }
     return(TRUE)
