@@ -1,7 +1,10 @@
 "are.parkap.valid" <-
 function(para) {
     if(! is.kap(para)) return(FALSE)
-    if(para$ifail == 2) return(FALSE)
+    # The ifail==2 case is above the Generalized Logistic Line
+    # if the length is one, then the ifail is present and we
+    # should test it.
+    if(length(para$ifail) == 1 && para$ifail == 2) return(FALSE)
     U <- para$para[1]
     A <- para$para[2]
     G <- para$para[3]
@@ -14,7 +17,7 @@ function(para) {
       warning("Parameters are invalid")
       return(FALSE)
     }
-    if(H < 0 & G*H <= -1) {
+    if(H < 0 && G*H <= -1) {
       warning("Parameters are invalid")
       return(FALSE)
     }
