@@ -1,8 +1,9 @@
 "freq.curve.kap" <-
 function(fs,para) {
-  if(! INT.check.fs(fs)) return()
+  if(! check.fs(fs)) return()
   if(! is.kap(para)) return()
-  Q <- matrix(nrow = length(fs), ncol = 1)
+  Q <- vector(mode="numeric",length = length(fs))
+  if(! are.parkap.valid(para)) return(Q)
   for(i in seq(1,length(fs))) {
     Q[i] <- quakap(fs[i],para)
   }
