@@ -1,6 +1,6 @@
 "pargam" <-
 function(lmom) {
-    para <- matrix(nrow = 2, ncol = 1)
+    para <- vector(mode="numeric", length=2)
     # METHOD: RATIONAL APPROXIMATION IS USED TO EXPRESS ALPHA AS A FUNCTION
     # OF L-CV. RELATIVE ACCURACY OF THE  APPROXIMATION IS BETTER THAN 5E-5.
     #
